package jdk.internal.jshell.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "11.0.9+11" },
            { "jdk", "11.0.9" },
            { "release", "11.0.9" },
        };
    }
}
